/**
 * Copyright 2011 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.mithrim.epf.core.common;


/**
 * An <code>AttributeType</code> defines the name, occurrence and semantic role
 * of a payload attribute.
 *
 * @author Dirk Jablonski
 */
public final class AttributeType {
	public static final String DEFAULT_DATA_TYPE = String.class.getName();
	public static final PayloadAttributeOccurrence DEFAULT_OCCURRENCE = PayloadAttributeOccurrence.OPTIONAL;

	private String name;
	private String dataType;
	private PayloadAttributeOccurrence occurrence;
	private String semanticRole;

	public AttributeType() {
		this(null, DEFAULT_DATA_TYPE, DEFAULT_OCCURRENCE);
	}

	public AttributeType(final String name) {
		this(name, DEFAULT_DATA_TYPE, DEFAULT_OCCURRENCE);
	}

	public AttributeType(final String name, final String dataType) {
		this(name, dataType, DEFAULT_OCCURRENCE);
	}

	public AttributeType(final String name, final PayloadAttributeOccurrence occurrence) {
		this(name, DEFAULT_DATA_TYPE, occurrence);
	}

	public AttributeType(final String name, final String dataType, final PayloadAttributeOccurrence occurrence) {
		this.name = name;
		this.dataType = dataType;
		this.occurrence = occurrence;
	}

	/**
	 * @return the name
	 */
	public String getName() {
		return name;
	}

	/**
	 * @param name the name to set
	 */
	public void setName(final String name) {
		this.name = name;
	}

	/**
	 * @return the dataType
	 */
	public String getDataType() {
		return dataType;
	}

	/**
	 * @param dataType the dataType to set
	 */
	public void setDataType(final String dataType) {
		this.dataType = dataType;
	}

	/**
	 * @return the occurrence
	 */
	public PayloadAttributeOccurrence getOccurrence() {
		return occurrence;
	}

	/**
	 * @param occurrence the occurrence to set
	 */
	public void setOccurrence(final PayloadAttributeOccurrence occurrence) {
		this.occurrence = occurrence;
	}

	/**
	 * @return the semanticRole
	 */
	public String getSemanticRole() {
		return semanticRole;
	}

	/**
	 * @param semanticRole the semanticRole to set
	 */
	public void setSemanticRole(final String semanticRole) {
		this.semanticRole = semanticRole;
	}
}
