/**
 * Copyright 2011 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.mithrim.epf.core.common;

/**
 * A <code>ContextInitiatorPolicy</code> is a semantic abstraction that defines the
 * behavior required when a window has been opened and a subsequent initiator event
 * is detected.
 * The possible policies are open another window, ignore the new initiator event,
 * refresh the window, or extend the window.
 *
 * @author Dirk Jablonski
 */
public enum ContextInitiatorPolicy {
	/**
	 * A new window is opened, alongside the existing one.
	 */
	ADD,

	/**
	 * The original window is preserved.
	 */
	IGNORE,

	/**
	 * The original window is closed, and a new window is opened.
	 */
	REFRESH,

	/**
	 * The timeout processing (expiration event count or expiration time offset)
	 * is reset to start with the new initiator event.
	 */
	EXTEND
}
