/**
 * Copyright 2011 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.mithrim.epf.core.common;

import java.util.Set;

import org.mithrim.epf.core.EventChannelInputAdapter;
import org.mithrim.epf.core.event.Event;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * 
 *
 * @author Dirk Jablonski
 */
public class DefaultOutputTerminal implements OutputTerminal {
	/**
	 * The logger for this class.
	 */
	private static final Logger logger = LoggerFactory.getLogger(DefaultOutputTerminal.class);

	/**
	 * The identifier of this output terminal.
	 */
	private String id;

	/**
	 * The list of {link EventType} IDs to process events from this input terminal.
	 */
	private Set<String> acceptedEventTypeIds;

	/**
	 * The targets (event channels) to send events to.
	 */
	private Set<EventChannelInputAdapter> targets;

	/* (non-Javadoc)
	 * @see org.mithrim.epf.core.common.OutputTerminal#isAcceptedType(java.lang.String)
	 */
	@Override
	public boolean isAcceptedType(final String eventTypeId) {
		return (null != acceptedEventTypeIds && acceptedEventTypeIds.contains(eventTypeId));
	}

	/* (non-Javadoc)
	 * @see org.mithrim.epf.core.common.OutputTerminal#send(org.mithrim.epf.core.event.Event)
	 */
	@Override
	public boolean send(final Event event) {
		if (null != getAcceptedEventTypeIds() && getAcceptedEventTypeIds().contains(event.getTypeId())) {
			if (null != targets)  {
				for (EventChannelInputAdapter target : targets) {
					target.send(event);
				}
			}
		}
		else {
			logger.trace("Event {} with type {} is not of any accepted type, ignoring", event.getId(), event.getTypeId());
		}

		return true;
	}

	/* (non-Javadoc)
	 * @see org.mithrim.epf.core.common.OutputTerminal#getId()
	 */
	@Override
	public String getId() {
		return id;
	}

	public void setId(final String id) {
		this.id = id;
	}

	protected Set<String> getAcceptedEventTypeIds() {
		return acceptedEventTypeIds;
	}

	/* (non-Javadoc)
	 * @see org.mithrim.epf.core.common.OutputTerminal#setAcceptedEventTypeIds(java.util.Set)
	 */
	@Override
	public void setAcceptedEventTypeIds(final Set<String> acceptedEventTypeIds) {
		this.acceptedEventTypeIds = acceptedEventTypeIds;
	}

	protected Set<EventChannelInputAdapter> getTargets() {
		return targets;
	}

	/* (non-Javadoc)
	 * @see org.mithrim.epf.core.common.OutputTerminal#setTargets(java.util.Set)
	 */
	@Override
	public void setTargets(final Set<EventChannelInputAdapter> targets) {
		this.targets = targets;
	}
}
