/**
 * Copyright 2011 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.mithrim.epf.core.consumer;

import java.util.Set;

import org.mithrim.epf.core.EventConsumer;
import org.mithrim.epf.core.common.EventHandler;
import org.mithrim.epf.core.common.InputTerminal;
import org.mithrim.epf.core.event.Event;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * 
 *
 * @author Dirk Jablonski
 */
public class DefaultEventConsumer implements EventConsumer {
	/**
	 * The logger for this class.
	 */
	private static final Logger logger = LoggerFactory.getLogger(DefaultEventConsumer.class);

	/**
	 * The identifier of this consumer.
	 */
	private String id;

	/**
	 * The {@link InputTerminal} to receive events on.
	 */
	private Set<InputTerminal> inputTerminals;

	/**
	 * The {link EventHandler} to handle events received by this consumer.
	 */
	private EventHandler eventHandler;

	@Override
	public void handleEvent(final Event event) {
		if (null != eventHandler) {
			eventHandler.handleEvent(event);
		}
	}

	/* (non-Javadoc)
	 * @see org.mithrim.epf.core.EventConsumer#getId()
	 */
	@Override
	public String getId() {
		return id;
	}

	public void setId(final String id) {
		this.id = id;
	}

	protected Set<InputTerminal> getInputTerminals() {
		return inputTerminals;
	}

	/* (non-Javadoc)
	 * @see org.mithrim.epf.core.EventConsumer#setInputTerminals(java.util.Set)
	 */
	@Override
	public void setInputTerminals(final Set<InputTerminal> inputTerminals) {
		this.inputTerminals = inputTerminals;

		if (null != inputTerminals) {
			for (InputTerminal terminal : inputTerminals) {
				terminal.setEventHandler(this);
			}
		}
	}

	protected EventHandler getEventHandler() {
		return eventHandler;
	}

	/* (non-Javadoc)
	 * @see org.mithrim.epf.core.EventConsumer#setEventHandler(org.mithrim.epf.core.common.EventHandler)
	 */
	@Override
	public void setEventHandler(final EventHandler handler) {
		this.eventHandler = handler;
	}

}
