/**
 * Copyright 2011 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.mithrim.epf.core.event;

import java.util.HashMap;
import java.util.Map;
import java.util.Set;

import org.mithrim.epf.core.EventType;

/**
 *
 *
 * @author Dirk Jablonski
 */
public final class EventBuilderFactory {
	private Map<String, EventType> eventTypeMap;

	public EventBuilder createEventBuilder(final String eventTypeId) {
		if (null == eventTypeId) {
			throw new IllegalArgumentException("eventTypeId must not be null");
		}

		if (null == eventTypeMap.get(eventTypeId)) {
			throw new IllegalArgumentException("eventTypeId is unknown, unable to create EventBuilder");
		}

		return new EventBuilder(eventTypeMap.get(eventTypeId));
	}

	public void setEventTypes(final Set<EventType> eventTypes) {
		if (null == eventTypes || eventTypes.isEmpty()) {
			throw new IllegalArgumentException("eventTypes must not be null or empty");
		}

		eventTypeMap = new HashMap<String, EventType>(eventTypes.size());

		for (EventType type : eventTypes) {
			eventTypeMap.put(type.getId(), type);
		}
	}

}
